pub trait RevocationChecker {
// Required method
fn check(&self, cert: &Certificate) -> Result<(), SmimeError>;
}Expand description
Trait for checking certificate revocation status during signature verification.
This crate makes no network calls. Callers that need OCSP or CRL checking
implement this trait and inject it into crate::verify().
The no-op implementation NoRevocationCheck is provided for cases where
revocation checking is not needed (e.g. tests, trusted internal PKI,
air-gapped deployments).
Required Methods
Sourcefn check(&self, cert: &Certificate) -> Result<(), SmimeError>
fn check(&self, cert: &Certificate) -> Result<(), SmimeError>
Check whether cert has been revoked.
Return Ok(()) if the certificate is valid (not revoked or revocation
status is acceptable). Return Err(SmimeError::CertChain(...)) if the
certificate is revoked or its revocation status cannot be confirmed.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".